IncomingCallScreen class
Displays an incoming call screen with caller info, and accept/decline buttons.
This is a StatelessWidget with zero animation controllers or timers for maximum performance. All state is managed externally via callbacks.
IncomingCallScreen(
callerName: 'Sarah Johnson',
callerAvatarUrl: 'https://example.com/avatar.jpg',
callType: CallType.video,
onAccept: () => navigateToCallScreen(),
onDecline: () => Navigator.pop(context),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- IncomingCallScreen
Constructors
- IncomingCallScreen({Key? key, required String callerName, String? callerAvatarUrl, CallType callType = CallType.audio, CallTheme theme = const CallTheme.whatsApp(), CallStrings? strings, required VoidCallback onAccept, required VoidCallback onDecline})
-
Creates an IncomingCallScreen.
const
Properties
- callerAvatarUrl → String?
-
Optional avatar URL for the caller.
final
- callerName → String
-
The name of the caller displayed prominently.
final
- callType → CallType
-
The type of incoming call (audio or video).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onAccept → VoidCallback
-
Called when the accept button is tapped.
final
- onDecline → VoidCallback
-
Called when the decline button is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strings → CallStrings?
-
Localised strings. Defaults to CallStrings.english.
final
- theme → CallTheme
-
The visual theme. Defaults to CallTheme.whatsApp.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited